@@ -3,19 +3,6 @@
 
 #pragma once
 
-#include "intmath.hpp"
-
-#include <type_traits>
-#include <list>
-#include <vector>
-#include <map>
-#include <unordered_map>
-#include <mutex>
-#include <condition_variable>
-#include <deque>
-#include <thread>
-#include <functional>
-
 namespace netxs::generics
 {
     // generics: .
@@ -855,9 +842,9 @@ namespace netxs::generics
         void execute(size_t alonecmd, Out& story) const
         {
             auto& queue = In::fake();
-            if (alonecmd < this->size())
+            if (alonecmd < bulk::size())
             {
-                if (auto const& next = this->at(alonecmd))
+                if (auto const& next = bulk::at(alonecmd))
                 {
                     if (next.proc)
                     {
@@ -930,7 +917,7 @@ namespace netxs::generics
             forward.clear();
         }
         template<class K>
-        auto erase(K&& key )
+        auto erase(K&& key)
         {
             auto storage_it = storage.find(std::forward<K>(key));
             if (storage_it != storage.end())
@@ -946,7 +933,7 @@ namespace netxs::generics
             return faux;
         }
         template<class K>
-        auto contains(K&& key )
+        auto contains(K&& key)
         {
             return storage.contains(std::forward<K>(key));
         }
@@ -1009,6 +996,113 @@ namespace netxs::generics
             return guard{ *this };
         }
     };
+
+    // generics: Waitable object.
+    class waitable
+    {
+        using utex = std::recursive_mutex;
+        using cond = std::condition_variable_any;
+        using Lock = std::unique_lock<utex>;
+
+        utex mutex; // waitable: Access mutex.
+        cond synch; // waitable: Access notificator.
+        Lock guard; // waitable: Access lock.
+        flag ready; // waitable: Connection status.
+
+    public:
+        waitable()
+            : guard{ mutex },
+              ready{       }
+        { }
+
+        void notify()
+        {
+            ready.exchange(true);
+            synch.notify_all();
+        }
+        bool notified()
+        {
+            return ready;
+        }
+        auto wait_for(span timeout)
+        {
+            return synch.wait_for(guard, timeout, [&]{ return !!ready; });
+        }
+        void wait()
+        {
+            if (!ready)
+            {
+                synch.wait(guard);
+            }
+        }
+    };
+
+    // generics: Coroutine evaluation generator (pre C++23).
+    template<class T>
+    struct generator
+    {
+        struct promise_type
+        {
+            T const* current_value;
+
+            auto get_return_object()      { return generator{ handle_type::from_promise(*this) }; }
+            auto initial_suspend()        { return std::suspend_always{}; }
+            auto final_suspend() noexcept { return std::suspend_always{}; }
+            auto unhandled_exception()    { std::terminate(); }
+            auto return_void()            { }
+            auto yield_value(T const& value)
+            {
+                current_value = std::addressof(value);
+                return std::suspend_always{};
+            }
+        };
+
+        using handle_type = std::coroutine_handle<promise_type>;
+
+        handle_type h;
+
+        generator(generator const&) = delete;
+        generator(generator&& other) noexcept
+            : h{ std::exchange(other.h, nullptr) }
+        { }
+        generator(handle_type h)
+            : h{ h }
+        { }
+        ~generator()
+        {
+            if (h) h.destroy();
+        }
+
+        struct iterator
+        {
+            handle_type h;
+            bool        done;
+
+            void operator++()                            { h.resume(); done = h.done(); }
+            auto& operator*() const                      { return *(h.promise().current_value); }
+            auto operator!=(iterator const& other) const { return done != other.done; }
+        };
+
+        auto begin()
+        {
+            if (!h) return iterator{ nullptr, true };
+            h.resume();
+            return iterator{ h, h.done() };
+        }
+        auto end()
+        {
+            return iterator{ nullptr, true };
+        }
+        static generator merge(generator g1, generator g2)
+        {
+            for (auto& item : g1) co_yield item;
+            for (auto& item : g2) co_yield item;
+        }
+        friend auto operator | (generator&& g1, generator&& g2)
+        {
+            return merge(std::move(g1), std::move(g2));
+        }
+    };
 }
 
 // generics: Map helpers.
