@@ -5,22 +5,32 @@
 
 #include "utf.hpp"
 #include "generics.hpp"
-
-#if defined(__linux__) || defined(__APPLE__)
-    #include <stdint.h>
-#endif
+#include "ptr.hpp"
 
 namespace netxs
 {
     using fifo = generics::fifo<si32>;
 
+    // geometry: Generic 2D point.
+    template<class T>
+    struct limits
+    {
+        using type = T;
+        T min;
+        T max;
+        friend auto& operator << (std::ostream& s, limits p)
+        {
+            return s << "{ min:" << p.min << ", max:" << p.max << " }";
+        }
+    };
     // geometry: Generic 2D point.
     template<class T>
     struct xy2d
     {
         using type = T;
 
-        T x, y;
+        T x;
+        T y;
 
         template<class D>
         constexpr static auto cast(D x) requires(std::is_floating_point_v<T> || (std::is_integral_v<T> == std::is_integral_v<D>))
@@ -69,7 +79,7 @@ namespace netxs
             if (changed) *this = p;
             return changed;
         }
-        constexpr explicit operator bool()   const { return x != T{} || y != T{};      }
+        constexpr explicit operator bool ()  const { return x != T{} || y != T{};      }
         constexpr auto& operator [] (si32 i)       { return i ? y : x;                 }
         constexpr auto& operator [] (si32 i) const { return i ? y : x;                 }
         constexpr auto& operator ++ ()             { ++x; ++y;           return *this; }
@@ -104,10 +114,10 @@ namespace netxs
         //xy2d operator << (T i) const { return { x << i, y << i }; }
         //xy2d operator >> (T i) const { return { x >> i, y >> i }; }
 
-        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator +  (D i) const { return xy2d<D>{ x + i, y + i }; }
-        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator -  (D i) const { return xy2d<D>{ x - i, y - i }; }
-        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator *  (D i) const { return xy2d<D>{ x * i, y * i }; }
-        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator /  (D i) const { return xy2d<D>{ x / i, y / i }; }
+        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator +  (D i) const { return xy2d{ x + i, y + i }; }
+        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator -  (D i) const { return xy2d{ x - i, y - i }; }
+        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator *  (D i) const { return xy2d{ x * i, y * i }; }
+        template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator /  (D i) const { return xy2d{ x / i, y / i }; }
         template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator +  (xy2d<D> f) const { return xy2d{ x + f.x, y + f.y }; }
         template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator -  (xy2d<D> f) const { return xy2d{ x - f.x, y - f.y }; }
         template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator *  (xy2d<D> f) const { return xy2d{ x * f.x, y * f.y }; }
@@ -117,6 +127,10 @@ namespace netxs
         template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator *= (xy2d<D> f)       { x = cast(x * f.x); y = cast(y * f.y); return *this; }
         template<class D, class = std::enable_if_t<std::is_arithmetic_v<D>>> constexpr auto operator /= (xy2d<D> f)       { x = cast(x / f.x); y = cast(y / f.y); return *this; }
 
+        auto hypot() const
+        {
+            return std::hypot(x, y);
+        }
         xy2d   less(xy2d what, xy2d if_yes, xy2d if_no) const
         {
             return { x < what.x ? if_yes.x : if_no.x,
@@ -202,7 +216,7 @@ namespace netxs
     static constexpr auto dot_22 = twod{ 2,2 };
     static constexpr auto dot_21 = twod{ 2,1 };
     static constexpr auto dot_33 = twod{ 3,3 };
-    static constexpr auto dot_mx = twod{ (si32)(si32max / 2.f), (si32)(si32max / 2.f) };
+    static constexpr auto dot_mx = twod{ (si32)(fp32)(si32max / 2), (si32)(fp32)(si32max / 2) }; // Be sure that fp2d{ dot_mx } == twod{ dot_mx }.
 
     twod divround(twod p, si32 n) { return { divround(p.x, n  ), divround(p.y, n  ) }; }
     twod divround(si32 n, twod p) { return { divround(n  , p.x), divround(n  , p.y) }; }
@@ -224,9 +238,14 @@ namespace std
 namespace netxs
 {
     // geometry: Rectangle.
-    struct rect
+    template<class T>
+    struct xysz
     {
-        twod coor, size;
+        using twod = xy2d<T>;
+        using rect = xysz<T>;
+
+        twod coor;
+        twod size;
 
         bool operator == (rect const&) const = default;
         explicit operator bool ()       const { return size.x != 0 && size.y != 0;            }
@@ -268,7 +287,7 @@ namespace netxs
         constexpr twod clamp(twod point) const
         {
             auto [min, max] = twod::sort(coor, coor + size);
-            return std::clamp(point, min, max - dot_11);
+            return std::clamp(point, min, std::max(min, max - dot_11)); // Use std::max for zero size cases.
         }
         // rect: Is the point inside the rect.
         constexpr bool hittest(twod p) const
@@ -285,20 +304,35 @@ namespace netxs
             return test;
         }
         // rect: Return rect with specified orientation.
-        constexpr rect rotate(twod dir) const
+        constexpr rect rotate(twod dir) const requires(std::is_integral_v<T>)
         {
             auto sx = (dir.x ^ size.x) < 0;
             auto sy = (dir.y ^ size.y) < 0;
             return {{ sx ?  coor.x + size.x : coor.x, sy ?  coor.y + size.y : coor.y },
                     { sx ? -size.x          : size.x, sy ? -size.y          : size.y }};
         }
+        // rect: Return rect with specified orientation.
+        constexpr rect rotate(twod dir) const requires(std::is_floating_point_v<T>)
+        {
+            auto sx = std::signbit(dir.x) != std::signbit(size.x);
+            auto sy = std::signbit(dir.y) != std::signbit(size.y);
+            return {{ sx ?  coor.x + size.x : coor.x, sy ?  coor.y + size.y : coor.y },
+                    { sx ? -size.x          : size.x, sy ? -size.y          : size.y }};
+        }
         // rect: Change orientation.
-        constexpr auto& rotate_itself(twod dir)
+        constexpr auto& rotate_itself(twod dir) requires(std::is_integral_v<T>)
         {
             if ((dir.x ^ size.x) < 0) { coor.x += size.x; size.x = -size.x; }
             if ((dir.y ^ size.y) < 0) { coor.y += size.y; size.y = -size.y; }
             return *this;
         }
+        // rect: Change orientation.
+        constexpr auto& rotate_itself(twod dir) requires(std::is_floating_point_v<T>)
+        {
+            if (std::signbit(dir.x) != std::signbit(size.x)) { coor.x += size.x; size.x = -size.x; }
+            if (std::signbit(dir.y) != std::signbit(size.y)) { coor.y += size.y; size.y = -size.y; }
+            return *this;
+        }
         // rect: Return rect with top-left orientation.
         constexpr rect normalize() const
         {
@@ -318,7 +352,7 @@ namespace netxs
         constexpr rect trunc(twod edge) const
         {
             auto r = rect{};
-            r.coor = std::clamp(coor, dot_00, edge);
+            r.coor = std::clamp(coor, r.coor, edge);
             r.size = std::clamp(size, -coor, edge - coor) + coor - r.coor;
             return r;
         }
@@ -368,16 +402,17 @@ namespace netxs
         // rect: Change endianness to LE.
         friend auto letoh(rect r)
         {
-            return rect{ netxs::letoh(r.coor), netxs::letoh(r.size) };
+            return rect{ letoh(r.coor), letoh(r.size) };
         }
     };
 
+    using rect = xysz<si32>;
     using regs = std::vector<rect>;
 
-    static constexpr auto rect_00 = rect{ dot_00,dot_00 };
-    static constexpr auto rect_11 = rect{ dot_00,dot_11 };
+    static constexpr auto rect_00 = rect{ dot_00, dot_00 };
+    static constexpr auto rect_11 = rect{ dot_00, dot_11 };
 
-    // geometry: Padding around the rect.
+    // geometry: Padding around the rect: l, r, t, b.
     struct dent
     {
         si32 l, r, t, b;
@@ -385,6 +420,9 @@ namespace netxs
         constexpr dent(si32 l = 0, si32 r = 0, si32 t = 0, si32 b = 0)
             : l{ l }, r{ r }, t{ t }, b{ b }
         { }
+        constexpr dent(twod p)
+            : l{ p.x }, r{ p.x }, t{ p.y }, b{ p.y }
+        { }
         constexpr dent(dent const&) = default;
         constexpr dent& operator = (dent const&) = default;
         constexpr bool operator == (dent const&) const = default;
@@ -644,6 +682,7 @@ namespace netxs
             return "{ reg:" + region.str() + " win:" + window.str() +
                     " ovr:" + beyond.str() + " }";
         }
+        constexpr bool operator == (rack const&) const = default;
         friend auto& operator << (std::ostream& s, rack const& p)
         {
             return s << p.str();
