@@ -3,21 +3,48 @@
 
 #pragma once
 
-#include <array>
-#include <vector>
-#include <optional>
 #include <algorithm>
-#include <limits>
-#include <cmath>
-#include <cfenv>
-#include <cassert>
 #include <any>
-#include <bit>
+#include <array>
 #include <atomic>
+#include <bit>
+#include <bitset>
+#include <cassert>
+#include <cfenv>
+#include <charconv>
+#include <chrono>
+#include <cmath>
+#include <condition_variable>
+#include <coroutine>
+#include <cstdint>
 #include <cstring> // std::memcpy
-#include <utility> // std::cmp_equal
+#include <deque>
+#include <fstream>
+#include <filesystem>
+#include <functional>
+#include <future>
+#include <iterator>
+#include <limits>
+#include <list>
+#include <map>
+#include <memory>
+#include <mutex>
 #include <numeric> // std::accumulate
+#include <optional>
+#include <span>
+#include <sstream>
+#include <string>
+#include <string_view>
+#include <thread>
+#include <type_traits>
 #include <typeindex>
+#include <unordered_map>
+#include <unordered_set>
+#include <utility> // std::cmp_equal
+#include <vector>
+#include <variant>
+#include <ranges>  // std::views::reverse
+#include <regex>
 
 #ifndef faux
     #define faux (false)
@@ -42,7 +69,8 @@ namespace netxs
     using flag = std::atomic<bool>;
     using many = std::vector<std::any>;
 
-    constexpr size_t operator "" _sz (unsigned long long i) { return static_cast<size_t>(i); }
+    constexpr size_t operator ""_sz (unsigned long long i) { return static_cast<size_t>(i); }
+    static constexpr auto pi = 3.14159265358979323846;
     static constexpr auto bytemin = std::numeric_limits<byte>::min();
     static constexpr auto bytemax = std::numeric_limits<byte>::max();
     static constexpr auto int8min = std::numeric_limits<int8>::min();
@@ -65,6 +93,8 @@ namespace netxs
     static constexpr auto fp64min = std::numeric_limits<fp64>::lowest();
     static constexpr auto fp32epsilon = std::numeric_limits<fp32>::min();
     static constexpr auto fp64epsilon = std::numeric_limits<fp64>::min();
+    static constexpr auto fp32nan = std::numeric_limits<fp32>::quiet_NaN();
+    static constexpr auto fp64nan = std::numeric_limits<fp64>::quiet_NaN();
     static constexpr auto debugmode
         #if defined(DEBUG)
         = true;
@@ -72,20 +102,24 @@ namespace netxs
         = faux;
         #endif
 
-    static auto _k0 = 0; // LCtrl+Wheel.
-    static auto _k1 = 0; // Alt+Wheel.
-    static auto _k2 = 0; // LCtrl+Alt+Wheel.
-    static auto _k3 = 0; // RCtrl+Wheel.
+    [[maybe_unused]] static auto _k0 = 0; // LCtrl+Wheel.
+    [[maybe_unused]] static auto _k1 = 0; // Alt+Wheel.
+    [[maybe_unused]] static auto _k2 = 0; // LCtrl+Alt+Wheel.
+    [[maybe_unused]] static auto _k3 = 0; // RCtrl+Wheel.
 
-    struct noop
+    template<bool PredicateReturn>
+    struct base_noop
     {
-        constexpr auto operator()(auto&&...)
+        constexpr auto operator () (auto&&...)
         {
-            return faux;
+            return PredicateReturn;
             //return *this;
         }
-        //constexpr operator bool() const { return faux; }
+        constexpr operator bool () const { return faux; }
+        constexpr base_noop(auto&&...) { }
     };
+    using noop = base_noop<faux>;
+    using always_true = base_noop<true>;
 
     enum class feed : byte { none, rev, fwd };
 
@@ -142,6 +176,19 @@ namespace netxs
         return value.type() == typeid(T) ? std::any_cast<T>(value)
                                          : fallback;
     }
+    template<ui64 FieldMask>
+    static constexpr si32 field_offset()
+    {
+        auto mask = FieldMask;
+        if (mask == 0) return 0;
+        auto n = 0;
+        while ((mask & 1) == 0)
+        {
+            mask >>= 1;
+            ++n;
+        }
+        return n;
+    }
     // intmath: Set a single p-bit to v.
     template<sz_t P, class T>
     void set_bit(T&& n, bool v)
@@ -167,48 +214,25 @@ namespace netxs
     template<class T, class = std::enable_if_t<std::is_arithmetic_v<T>>>
     constexpr auto swap_bytes(T i)
     {
-        T r;
-        auto src = (byte*)&i;
-        auto dst = (byte*)&r;
-        if constexpr (sizeof(T) == 2)
-        {
-            dst[0] = src[1];
-            dst[1] = src[0];
-        }
-        else if constexpr (sizeof(T) == 4)
-        {
-            dst[0] = src[3];
-            dst[1] = src[2];
-            dst[2] = src[1];
-            dst[3] = src[0];
-        }
-        else if constexpr (sizeof(T) == 8)
-        {
-            dst[0] = src[7];
-            dst[1] = src[6];
-            dst[2] = src[5];
-            dst[3] = src[4];
-            dst[4] = src[3];
-            dst[5] = src[2];
-            dst[6] = src[1];
-            dst[7] = src[0];
-        }
-        else assert(faux);
-        return r;
+        auto r = std::bit_cast<std::array<byte, sizeof(T)>>(i);
+        std::ranges::reverse(r);
+        return std::bit_cast<T>(r);
     }
+    static constexpr auto endian_BE = std::endian::native == std::endian::big;
+    static constexpr auto endian_LE = std::endian::native == std::endian::little;
     // intmath: Convert LE to host endianness.
-    template<class T, bool BE = std::endian::native == std::endian::big>
+    template<class T>
     constexpr auto letoh(T i)
     {
-        if constexpr (BE && sizeof(T) > 1) return swap_bytes(i);
-        else                               return i;
+        if constexpr (endian_BE && sizeof(T) > 1) return swap_bytes(i);
+        else                                      return i;
     }
     // intmath: Convert BE to host endianness.
-    template<class T, bool LE = std::endian::native == std::endian::little>
+    template<class T>
     constexpr auto betoh(T i)
     {
-        if constexpr (LE && sizeof(T) > 1) return swap_bytes(i);
-        else                               return i;
+        if constexpr (endian_LE && sizeof(T) > 1) return swap_bytes(i);
+        else                                      return i;
     }
     // intmath: Get the aligned integral value.
     template<class T>
@@ -267,6 +291,12 @@ namespace netxs
         { }
     };
 
+    // intmath: Converting from radians to degrees.
+    template<class T>
+    T rad2deg(T rad)
+    {
+        return rad * (180.0 / netxs::pi);
+    }
     // intmath: Summ and return TRUE in case of unsigned integer overflow and store result in accum.
     template<class T1, class T2>
     constexpr bool sum_overflow(T1& accum, T2 delta)
@@ -370,6 +400,11 @@ namespace netxs
                                                   : ((n - d / 2) / d);
     }
     template<class T1, class T2, class T3 = T2, class = std::enable_if_t<std::is_integral_v<T1> && std::is_integral_v<T2> && std::is_integral_v<T3>>>
+    constexpr T3 udivupper(T1 n, T2 d)
+    {
+        return 1 + (n - 1) / d;
+    }
+    template<class T1, class T2, class T3 = T2, class = std::enable_if_t<std::is_integral_v<T1> && std::is_integral_v<T2> && std::is_integral_v<T3>>>
     constexpr T3 divupper(T1 n, T2 d)
     {
         return n > 0 ? 1 + (n - 1) / d
@@ -562,7 +597,7 @@ namespace netxs
             :  r{ r },
               d1{ 1 / (r * r)},
               d2{ 1 / ((r - 1) * (r - 1)) },
-              a2{ 1 - d2 }, 
+              a2{ 1 - d2 },
               b2{ 3 * d2},
               c2{ -3 * d2}
         { }
@@ -592,7 +627,7 @@ namespace netxs
             : r{ r },
               d1{ 1 / (r * r)},
               d2{ 1 / ((r - 1) * (r - 1)) },
-              a2{ 1 - d2 }, 
+              a2{ 1 - d2 },
               b2{ 3 * d2},
               c2{ -3 * d2},
             offset_x{ offset_x },
@@ -747,7 +782,7 @@ namespace netxs
         auto dy = std::abs(src_size.x);
         if (src_view.size.x < 0) { dx = -dx; src_view.coor.x -= 1; }
         if (src_view.size.y < 0) { dy = -dy; src_view.coor.y -= 1; }
-        
+
         dst_view.size -= 1;
         auto sptr = bitmap.begin() + (src_view.coor.x + src_view.coor.y * src_size.x);
         auto dptr = canvas.begin() + (dst_view.coor.x + dst_view.coor.y * dst_size.x);
@@ -855,7 +890,7 @@ namespace netxs
         auto&  size() const { return _area.size;     }
         auto&  coor()       { return _area.coor;     }
         auto&  coor() const { return _area.coor;     }
-        auto& operator [] (auto p) { return*(begin() + p.x + p.y * _area.size.x); }
+        auto& operator [] (auto p) { return *(begin() + p.x + p.y * _area.size.x); }
         void size(auto new_size, auto... filler)
         {
             _area.size = new_size;
@@ -1234,7 +1269,7 @@ namespace netxs
         if (w <= r1) // All pixels on a line have the same average value.
         {
             auto s_end = s_ptr + s_hop;
-            auto d_end = d_ptr + d_hop;;
+            auto d_end = d_ptr + d_hop;
             while (true)
             {
                 auto accum = Accum_t{};
