@@ -15,8 +15,8 @@ import datetime
 import collections
 
 UNICODESPACE = 0x110000
-#ROOTURL = "https://www.unicode.org/Public/UNIDATA"
-ROOTURL = "https://www.unicode.org/Public/draft/UCD/ucd/"
+ROOTURL = "https://www.unicode.org/Public/UNIDATA"
+#ROOTURL = "https://www.unicode.org/Public/draft/UCD/ucd/"
 DATA_SOURCE = { 'GCBREAK' : (ROOTURL + '/auxiliary/GraphemeBreakProperty.txt',
                              ['CODERANGE', 'BREAK_CLASS']),
                 'EAWIDTH' : (ROOTURL + '/EastAsianWidth.txt',
@@ -121,6 +121,7 @@ WCWIDTHS = { 'zerowidth' : ['zero', 'non-printable' ],
 
 CUSTOMIZE = [('0200B',        'zero', 'Nonspacing_Mark', 'Extend'), # ZWSP, ZERO WIDTH SPACE is always part of grapheme cluster and can't be the first
              ('0200C',        'zero', 'Nonspacing_Mark', 'Extend'), # ZWNJ, ZERO WIDTH NON-JOINER is always part of grapheme cluster and can't be the first
+             ('0FE0F',        'wide', 'Nonspacing_Mark', 'Extend'), # VS16 changes width of the base character to 'wide'.
              ('D0000..D0FFF', 'zero', 'Nonspacing_Mark', 'Extend')]
 #def gc(x):
 #    return x * (x + 1) / 2 + 1
@@ -248,10 +249,6 @@ HEADER_BASE = r'''/**
 
 #pragma once
 
-#include <cstdint>
-#include <vector>
-#include <iterator>
-
 namespace netxs::unidata
 {{
     namespace widths
@@ -314,7 +311,7 @@ namespace netxs::unidata
 
         constexpr unidata& operator = (unidata const&) = default;
 
-        auto is_cmd()
+        auto is_cmd() const
         {{
             return control < cntrls::non_control;
         }}
@@ -419,7 +416,7 @@ namespace netxs::unidata
     {{
         static auto data = []
         {{
-            auto v = std::vector<ui16>(0x10FFFF); // ISO 15924 Script No: 0 - 999.
+            auto v = std::vector<ui16>(0x10FFFF + 1); // ISO 15924 Script No: 0 - 999.
             auto j = 0;
             auto s = 0;
             auto l = 0;
@@ -668,6 +665,9 @@ apply_nonprint(set(ZEROWIDTH), set(PRINTABLE), chrs)
 noncmd_id = apply_commands(set(CONTROLCP), NONCTRLCP, set(PRINTABLE), chrs)
 apply_wscripts(data.src['ISOCODS'], data.src['SCRIPTS'], chrs)
 
+ # Allow nulls to be printable.
+chrs[0].ucwidth = 'slim'
+
 # 00 33 7 555 00
 # ranges: 0,2 3,2 7,1 5,3 0,2
 script_ranges = []
